@@ -30,12 +30,7 @@ This method tries to download the asset from web.
 
 sub asset_for {
   my ($self, $url, $assetpack) = @_;
-  my $lookup = Mojolicious::Plugin::AssetPack::_name($url);
-
-  if (my $asset = $assetpack->_find('packed', qr{^$lookup\.\w+$})) {
-    $assetpack->_app->log->debug("Asset $url is fetched") if DEBUG;
-    return $asset;
-  }
+  my $name = Mojolicious::Plugin::AssetPack::_name($url);
 
   my $tx  = $assetpack->_ua->get($url);
   my $ct  = $tx->res->headers->content_type // 'text/plain';
@@ -47,8 +42,8 @@ sub asset_for {
 
   $ext = $ext->[0] if ref $ext;
   $ext = $tx->req->url->path =~ m!\.(\w+)$! ? $1 : 'txt' if !$ext or $ext eq 'bin';
-  $assetpack->_app->log->info("Asset $url was fetched");
-  $assetpack->_asset("$lookup.$ext")->content($tx->res->body);
+  $assetpack->_app->log->info("Asset $url was fetched successfully");
+  $assetpack->_asset("$name.$ext")->content($tx->res->body);
 }
 
 =head1 COPYRIGHT AND LICENSE
